pandasdmx package
=================

Subpackages
-----------

.. toctree::

    pandasdmx.reader
    pandasdmx.utils
    pandasdmx.writer

Submodules
----------

pandasdmx.api module
--------------------

.. automodule:: pandasdmx.api
    :members:
    :undoc-members:
    :show-inheritance:

pandasdmx.model module
----------------------

.. automodule:: pandasdmx.model
    :members:
    :undoc-members:
    :show-inheritance:

pandasdmx.remote module
-----------------------

.. automodule:: pandasdmx.remote
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pandasdmx
    :members:
    :undoc-members:
    :show-inheritance:
